Stan Math Library: stan/math/rev/scal/fun/step.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

step.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_STEP_HPP
2 #define STAN_MATH_REV_SCAL_FUN_STEP_HPP
3
4 #include <stan/math/rev/core.hpp>
5
6 namespace stan {
7 namespace math {
8
25 inline var step(const stan::math::var& a) {
26 return var(new vari(a.vi_->val_ < 0.0 ? 0.0 : 1.0));
27 }
28
29 }
30 }
31 #endif
core.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::vari
The variable implementation base class.
Definition: vari.hpp:30
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::vari::val_
const double val_
The value of this variable.
Definition: vari.hpp:38
stan::math::step
int step(const T y)
The step, or Heaviside, function.
Definition: step.hpp:29
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43

[ Stan Home Page ] © 2011–2016, Stan Development Team.